Welcome to sarwaveifrproc's documentation!
==========================================

.. image:: ./figures/cover.png
  :alt: cover
  :scale: 100 %
  :name: cover
  :align: center

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   product_description
   atbd
   bibliography
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
